#!/usr/bin/env python3
#
# Copyright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the COVIDChestXRay dataset."""

from tensorbay.opendataset.COVIDChestXRay.loader import COVIDChestXRay

__all__ = ["COVIDChestXRay"]
